package com.ynet.life.loaf;

import com.ynet.gene.core.Context;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.jdbc.LoafPreparedQuery;
import com.ynet.life.loaf.jdbc.LoafQueryCondition;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;

/* loaded from: com_ynet_life_loaf.jar:com/ynet/life/loaf/LOAFHelper.class */
public class LOAFHelper {
    public static String getICollName(TableConfig tableConfig) {
        Object[] objs = tableConfig.getDataToTableFieldHashMap().keySet().toArray();
        String iCollName = null;
        String[] valueFieldName = new String[objs.length];
        for (int i = 0; i < objs.length; i++) {
            valueFieldName[i] = (String) objs[i];
        }
        int i2 = 0;
        while (true) {
            if (i2 >= valueFieldName.length) {
                break;
            }
            int pos = valueFieldName[i2].indexOf(LoafConstants.ICOLL_FIELD_SEPARATOR);
            if (pos <= 0) {
                i2++;
            } else {
                iCollName = valueFieldName[i2].substring(0, pos);
                break;
            }
        }
        return iCollName;
    }

    public static void putIKCollToContext(Context context, TableConfig tableConfig, KeyedCollection kColl, String iCollName) {
        for (String fieldName : kColl.keySet()) {
            String fieldValue = (String) kColl.get(fieldName);
            String trueContextFieldName = (String) tableConfig.getContextFieldMap().get(String.valueOf(iCollName) + LoafConstants.ICOLL_FIELD_SEPARATOR + fieldName);
            if (trueContextFieldName != null && trueContextFieldName.length() > 0) {
                fieldValue = (String) context.get(trueContextFieldName);
            }
            context.put(String.valueOf(iCollName) + LoafConstants.ICOLL_FIELD_SEPARATOR + fieldName, fieldValue);
        }
    }

    public static void removeIKCollFromContext(Context context, KeyedCollection kColl, String iCollName) {
        for (String fieldName : kColl.keySet()) {
            String contextFieldName = String.valueOf(iCollName) + LoafConstants.ICOLL_FIELD_SEPARATOR + fieldName;
            if (context.containsKey(contextFieldName)) {
                context.removeDataElement(contextFieldName);
            }
        }
    }

    public static void saveChangeField(PreparedStatement statement, Context context, TableConfig tableConfig, String batchNo, int opType, Map changFieldMap) throws SQLException, TranFailException {
        LoafQueryCondition condition = new LoafQueryCondition(tableConfig, context);
        String tableName = tableConfig.getTableName();
        Trace.logDebug("LOAF", "输入参数列表--->(batchNo=" + batchNo + ", tableName=" + tableName + ", primaryKey=" + condition.toString() + ", opType=" + opType + ")");
        for (String tableFieldName : changFieldMap.keySet()) {
            String fieldName = (String) changFieldMap.get(tableFieldName);
            String fieldValue = (String) context.get(fieldName);
            if (fieldValue != null) {
                Trace.logDebug("LOAF", "field=" + tableFieldName + "       fieldValue=" + fieldValue);
                statement.setString(1, LifeDBAccess.getSequenceNo(statement.getConnection(), "IM_AUTH_QUEUE_BATCHNO"));
                statement.setString(2, batchNo);
                statement.setString(3, tableName);
                statement.setString(4, condition.toString());
                statement.setString(5, String.valueOf(opType));
                statement.setString(6, tableFieldName);
                statement.setString(7, fieldValue);
                statement.execute();
            }
        }
    }

    public static Map getChangeField(Connection connection, Context context, TableConfig tableConfig, int opType) throws SQLException {
        Map changeFieldMap = new HashMap();
        if (opType == 1 || opType == 4) {
            changeFieldMap = tableConfig.getTableFieldToDataHashMap();
        } else if (opType == 2) {
            changeFieldMap = getPrimaryKeyMap(tableConfig);
        } else if (opType == 3) {
            LoafQueryCondition queryCondition = new LoafQueryCondition(tableConfig, context);
            ResultSet resultSet = new LoafPreparedQuery(tableConfig, queryCondition, (String) null).getPreparedStatement(connection).executeQuery();
            if (resultSet.next()) {
                Map tableFieldMap = tableConfig.getTableFieldToDataHashMap();
                for (String tableField : tableFieldMap.keySet()) {
                    String dataField = (String) tableFieldMap.get(tableField);
                    String originalValue = resultSet.getString(tableField);
                    String newValue = (String) context.get(dataField);
                    if (newValue != null && newValue.length() > 0) {
                        if (originalValue == null || originalValue.length() == 0 || !newValue.equals(originalValue) || tableConfig.getPrimaryKeyHashMap().contains(tableField)) {
                            changeFieldMap.put(tableField, dataField);
                        }
                    } else if (newValue != null && newValue.length() == 0 && originalValue != null && originalValue.length() > 0) {
                        changeFieldMap.put(tableField, dataField);
                    }
                }
            }
            if (changeFieldMap.size() == 0) {
                changeFieldMap = getPrimaryKeyMap(tableConfig);
            }
        }
        return changeFieldMap;
    }

    private static Map getPrimaryKeyMap(TableConfig tableConfig) {
        Map primaryKeyMap = new HashMap();
        for (String primaryKeyTableField : tableConfig.getPrimaryKeyHashMap()) {
            String primaryKeyContextField = (String) tableConfig.getTableFieldToDataHashMap().get(primaryKeyTableField);
            primaryKeyMap.put(primaryKeyTableField, primaryKeyContextField);
        }
        return primaryKeyMap;
    }

    public static KeyedCollection getKCollOfChangeBean(LoafDataChangeBean changeBean, TableConfig tableConfig, String iCollName) {
        KeyedCollection kcoll = new KeyedCollection();
        Map tableFieldMap = tableConfig.getTableFieldToDataHashMap();
        for (String tableFieldName : tableFieldMap.keySet()) {
            String fieldName = (String) tableFieldMap.get(tableFieldName);
            String fieldValue = (String) changeBean.getFieldMap().get(tableFieldName);
            if (iCollName != null) {
                int separatorIndex = fieldName.indexOf(LoafConstants.ICOLL_FIELD_SEPARATOR);
                if (separatorIndex > 0) {
                    kcoll.put(fieldName.substring(separatorIndex + 1), fieldValue);
                }
            } else {
                kcoll.put(fieldName, fieldValue);
            }
        }
        kcoll.put(LoafConstants.OP_TYPE_NAME, String.valueOf(changeBean.getOpType()));
        return kcoll;
    }

    public static KeyedCollection getKCollOfResultSet(ResultSet resultSet, TableConfig tableConfig, String iCollName) throws SQLException {
        KeyedCollection kcoll = new KeyedCollection();
        Map tableFieldMap = tableConfig.getTableFieldToDataHashMap();
        for (String tableFieldName : tableFieldMap.keySet()) {
            String fieldName = (String) tableFieldMap.get(tableFieldName);
            String fieldValue = resultSet.getString(tableFieldName);
            if (iCollName != null) {
                int separatorIndex = fieldName.indexOf(LoafConstants.ICOLL_FIELD_SEPARATOR);
                if (separatorIndex > 0) {
                    kcoll.put(fieldName.substring(separatorIndex + 1), fieldValue);
                }
            } else {
                kcoll.put(fieldName, fieldValue);
            }
        }
        return kcoll;
    }
}
